# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkSettingsResponse(Model):
    """BenchmarkSettingsResponse.

    :param benchmark1: Benchmark factor 1
    :type benchmark1: ~energycap.sdk.models.BenchmarkWithUsedCountResponse
    :param benchmark2: Benchmark factor 2
    :type benchmark2: ~energycap.sdk.models.BenchmarkWithUsedCountResponse
    :param benchmark3: Benchmark factor 3
    :type benchmark3: ~energycap.sdk.models.BenchmarkWithUsedCountResponse
    """

    _attribute_map = {
        'benchmark1': {'key': 'benchmark1', 'type': 'BenchmarkWithUsedCountResponse'},
        'benchmark2': {'key': 'benchmark2', 'type': 'BenchmarkWithUsedCountResponse'},
        'benchmark3': {'key': 'benchmark3', 'type': 'BenchmarkWithUsedCountResponse'},
    }

    def __init__(self, benchmark1=None, benchmark2=None, benchmark3=None):
        super(BenchmarkSettingsResponse, self).__init__()
        self.benchmark1 = benchmark1
        self.benchmark2 = benchmark2
        self.benchmark3 = benchmark3



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionVoid(Model):
    """ListActionVoid.

    :param void:
    :type void: bool
    """

    _attribute_map = {
        'void': {'key': 'void', 'type': 'bool'},
    }

    def __init__(self, void=None):
        super(ListActionVoid, self).__init__()
        self.void = void



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkValueRequest(Model):
    """BenchmarkValueRequest.

    :param effective_date: The effective date for the benchmark <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type effective_date: datetime
    :param value: The benchmark value <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     precision of 6</span> <span class='property-internal'>Must be between 0
     and 1.79769313486232E+308</span> <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     precision of 6</span> <span class='property-internal'>Must be between 0
     and 1.79769313486232E+308</span>
    :type value: float
    """

    _validation = {
        'effective_date': {'required': True},
        'value': {'required': True, 'minimum': 0},
    }

    _attribute_map = {
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, effective_date, value):
        super(BenchmarkValueRequest, self).__init__()
        self.effective_date = effective_date
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFResponse(Model):
    """UDFResponse.

    :param udf_id:
    :type udf_id: int
    :param name:
    :type name: str
    :param udf_type:
    :type udf_type: str
    :param data_type:
    :type data_type: ~energycap.sdk.models.DataTypeResponse
    :param display_order:
    :type display_order: int
    :param udf_select_values:
    :type udf_select_values:
     list[~energycap.sdk.models.UDFSelectValueResponse]
    :param count:
    :type count: int
    """

    _attribute_map = {
        'udf_id': {'key': 'udfId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'udf_type': {'key': 'udfType', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'DataTypeResponse'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'udf_select_values': {'key': 'udfSelectValues', 'type': '[UDFSelectValueResponse]'},
        'count': {'key': 'count', 'type': 'int'},
    }

    def __init__(self, udf_id=None, name=None, udf_type=None, data_type=None, display_order=None, udf_select_values=None, count=None):
        super(UDFResponse, self).__init__()
        self.udf_id = udf_id
        self.name = name
        self.udf_type = udf_type
        self.data_type = data_type
        self.display_order = display_order
        self.udf_select_values = udf_select_values
        self.count = count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestSavingsMonthlyResponse(Model):
    """PlaceDigestSavingsMonthlyResponse.

    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_id: The place identifier
    :type place_id: int
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param global_use_unit: The use unit of measure
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit: The bodyline's cost unit of measure for this
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param commodities: An array of SavingsMonthly data per commodity
    :type commodities:
     list[~energycap.sdk.models.PlaceDigestSavingsMonthlyResponseCommodityData]
    :param results: An array of SavingsMonthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestSavingsMonthlyResponseResults]
    """

    _attribute_map = {
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'commodities': {'key': 'commodities', 'type': '[PlaceDigestSavingsMonthlyResponseCommodityData]'},
        'results': {'key': 'results', 'type': '[PlaceDigestSavingsMonthlyResponseResults]'},
    }

    def __init__(self, place_code=None, place_info=None, place_id=None, updated=None, global_use_unit=None, cost_unit=None, commodities=None, results=None):
        super(PlaceDigestSavingsMonthlyResponse, self).__init__()
        self.place_code = place_code
        self.place_info = place_info
        self.place_id = place_id
        self.updated = updated
        self.global_use_unit = global_use_unit
        self.cost_unit = cost_unit
        self.commodities = commodities
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UnitSystemTemplateChild(Model):
    """UnitSystemTemplateChild.

    :param template_id:
    :type template_id: int
    :param template_code:
    :type template_code: str
    :param template_info:
    :type template_info: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    """

    _attribute_map = {
        'template_id': {'key': 'templateId', 'type': 'int'},
        'template_code': {'key': 'templateCode', 'type': 'str'},
        'template_info': {'key': 'templateInfo', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
    }

    def __init__(self, template_id=None, template_code=None, template_info=None, commodity=None):
        super(UnitSystemTemplateChild, self).__init__()
        self.template_id = template_id
        self.template_code = template_code
        self.template_info = template_info
        self.commodity = commodity
